@@ -8,6 +8,7 @@ from iwf.iwf_api.models import SearchAttributeValueType
 class PersistenceFieldType(Enum):
     DataAttribute = 1
     SearchAttribute = 2
+    DataAttributePrefix = 3
 
 
 @dataclass
@@ -27,6 +28,12 @@ class PersistenceField:
             key, PersistenceFieldType.SearchAttribute, None, sa_type
         )
 
+    @classmethod
+    def data_attribute_prefix_def(cls, key: str, value_type: Optional[type]):
+        return PersistenceField(
+            key, PersistenceFieldType.DataAttributePrefix, value_type
+        )
+
 
 @dataclass
 class PersistenceSchema:
