@@ -3,6 +3,7 @@ from typing import Callable, Optional
 from iwf.communication_schema import CommunicationMethodType
 from iwf.errors import InvalidArgumentError, WorkflowDefinitionError
 from iwf.iwf_api.models import SearchAttributeValueType
+from iwf.persistence_options import PersistenceOptions
 from iwf.persistence_schema import PersistenceFieldType
 from iwf.rpc import RPCInfo
 from iwf.type_store import TypeStore, Type
@@ -18,6 +19,7 @@ class Registry:
     _signal_channel_type_store: dict[str, dict[str, Optional[type]]]
     _data_attribute_types: dict[str, TypeStore]
     _search_attribute_types: dict[str, dict[str, SearchAttributeValueType]]
+    _persistence_options: dict[str, PersistenceOptions]
     _rpc_infos: dict[str, dict[str, RPCInfo]]
 
     def __init__(self):
@@ -28,6 +30,7 @@ class Registry:
         self._signal_channel_type_store = dict()
         self._data_attribute_types = dict()
         self._search_attribute_types = {}
+        self._persistence_options = {}
         self._rpc_infos = dict()
 
     def add_workflow(self, wf: ObjectWorkflow):
@@ -37,6 +40,7 @@ class Registry:
         self._register_signal_channels(wf)
         self._register_data_attributes(wf)
         self._register_search_attributes(wf)
+        self._register_persistence_options(wf)
         self._register_workflow_rpcs(wf)
 
     def add_workflows(self, *wfs: ObjectWorkflow):
@@ -82,6 +86,9 @@ class Registry:
     ) -> dict[str, SearchAttributeValueType]:
         return self._search_attribute_types[wf_type]
 
+    def get_persistence_options(self, wf_type: str) -> PersistenceOptions:
+        return self._persistence_options[wf_type]
+
     def get_rpc_infos(self, wf_type: str) -> dict[str, RPCInfo]:
         return self._rpc_infos[wf_type]
 
@@ -141,6 +148,10 @@ class Registry:
                 types[field.key] = sa_type
         self._search_attribute_types[wf_type] = types
 
+    def _register_persistence_options(self, wf: ObjectWorkflow):
+        wf_type = get_workflow_type(wf)
+        self._persistence_options[wf_type] = wf.get_persistence_options()
+
     def _register_workflow_state(self, wf):
         wf_type = get_workflow_type(wf)
         state_map = {}
